/*
 * gpio.h
 *
 *  Created on: May 10, 2014
 *      Author: Miguel Angel Sanchez Muñoz
 */

#ifndef GPIO_H_
#define GPIO_H_

#include "LPC17xx.h"
#include "FreeRTOS.h"

/*-----------------------------------------------------------*/

/*****************************************************************************
** Function name:		GPIOSet
**
** Descriptions:		Set one GPIO as input or output
**
** parameters:			pin, direction (0 input, 1 output)
**
** Returned value:		None
**
*****************************************************************************/
void pinSet (uint8_t pin, uint8_t direction);

/*****************************************************************************
** Function name:		GPIOWrite
**
** Descriptions:		Writes a value on an output pin
**
** parameters:			pin, value to write ( 0 or 1 )
**
** Returned value:		None
**
*****************************************************************************/
void pinWrite ( uint8_t pin , uint8_t value );

/*****************************************************************************
** Function name:		GPIORead
**
** Descriptions:		Reads the value of an input pin
**
** parameters:			pin
**
** Returned value:		value of the input
**
*****************************************************************************/
uint32_t pinRead ( uint8_t pin );

/*****************************************************************************
** Function name:		pinToggle
**
** Descriptions:		Toggle pin
**
** parameters:			pin
**
** Returned value:		None
**
*****************************************************************************/
void pinToggle( uint8_t pin );

/*****************************************************************************
** Function name:		initEINT0
**
** Descriptions:		Initialize GPIO External Interruption 0 pin P2.10
**
** parameters:			none
**
** Returned value:		none
**
*****************************************************************************/
void initEINT0();

/*****************************************************************************
** Function name:		initEINT1
**
** Descriptions:		Initialize GPIO External Interruption 1 pin P2.11
**
** parameters:			none
**
** Returned value:		none
**
*****************************************************************************/
void initEINT1();

#endif /* GPIO_H_ */
