/*
 * motor.h
 *
 *  Created on: May 10, 2014
 *      Author: Miguel Angel Sanchez Muñoz
 */

#include "LPC17xx.h"
#include "FreeRTOS.h"
#include "delay.h"
#include "gpio.h"
#include "type.h"
#include "debug.h"
#include <stdio.h>
#include <stdlib.h>

#ifndef MOTOR_H_
#define MOTOR_H_

//#define DEBUG_MOTOR

/*-----------------------------------------------------------*/

/*****************************************************************************
** Function name:	Motor_Init
**
** Descriptions:	Initialize motor pins
**
** parameters:		Steep pin, Reset pin, Direction right pin, Direction left pin
** Returned value:	none
**
*****************************************************************************/
void Motor_Init(uint8_t steepPin, uint8_t resetPin, uint8_t dirRightPin, uint8_t dirLeftPin);

/*****************************************************************************
** Function name:	Motor_Steep
**
** Descriptions:	Generate one steep in steep pin
**
** parameters:		none
** Returned value:	none
**
*****************************************************************************/
void Motor_Steep(uint32_t speed);

/*****************************************************************************
** Function name:	Motor_Start
**
** Descriptions:	Start motor
**
** parameters:		none
** Returned value:	none
**
*****************************************************************************/
void Motor_Start();

/*****************************************************************************
** Function name:	Motor_Stop
**
** Descriptions:	Stop motor
**
** parameters:		none
** Returned value:	none
**
*****************************************************************************/
void Motor_Stop();

/*****************************************************************************
** Function name:	Motor_Go
**
** Descriptions:	Set forwards direction
**
** parameters:		none
** Returned value:	none
**
*****************************************************************************/
void Motor_Go();

/*****************************************************************************
** Function name:	Motor_Back
**
** Descriptions:	Set back direction
**
** parameters:		none
** Returned value:	none
**
*****************************************************************************/
void Motor_Back();

/*****************************************************************************
** Function name:	Motor_DirRight
**
** Descriptions:	Set right direction
**
** parameters:		none
** Returned value:	none
**
*****************************************************************************/
void Motor_DirRight();

/*****************************************************************************
** Function name:	Motor_DirLeft
**
** Descriptions:	Set left direction
**
** parameters:		none
** Returned value:	none
**
*****************************************************************************/
void Motor_DirLeft();

/*****************************************************************************
** Function name:	Motor_DirRandom
**
** Descriptions:	Set random direction
**
** parameters:		none
** Returned value:	none
**
*****************************************************************************/
void Motor_DirRandom();

#endif /* MOTOR_H_ */
