/*
 * wifly.h
 *
 *  Created on: Mar 24, 2014
 *      Author: Miguel Angel Sanchez Muñoz
 */

#ifndef WIFLY_H_
#define WIFLY_H_

#include "LPC17xx.h"
#include "uart.h"
#include "delay.h"
#include "printf.h"
#include "type.h"
#include "debug.h"

#include <string.h>
#include <stdio.h>
#include <stdlib.h>

#define RST_WIFLY_PIN 6

#define DEBUG_WIFLY

/*-----------------------------------------------------------*/

/*****************************************************************************
** Function name:		Wifly_INIT
**
** Descriptions:		Initialize UART of Wifly and hard reset Wifly
**
** parameters:			UART port,  baudrate
** Returned value:		none
**
*****************************************************************************/
void Wifly_INIT(uint8_t UARTportNum, uint32_t baudrate);

/*****************************************************************************
** Function name:		Wifly_Reboot
**
** Descriptions:		Send reboot command
**
** parameters:			UART port
** Returned value:		none
**
*****************************************************************************/
void Wifly_Reboot();

/*****************************************************************************
** Function name:		Wifly_Exit
**
** Descriptions:		Send exit command, to exit from command mode
**
** parameters:			UART port
** Returned value:		none
**
*****************************************************************************/
void Wifly_Exit();

/*****************************************************************************
** Function name:		Wifly_WlanConnection
**
** Descriptions:		Connect to a Wireless network
**
** parameters:			UART port, SSID, MODE, key phrase
** Returned value:		TRUE is connect ok
**
*****************************************************************************/
uint8_t Wifly_WlanConnection(uint8_t *ssid, uint8_t *mode, uint8_t *key);

/*****************************************************************************
** Function name:		Wifly_Ping
**
** Descriptions:		Send ping with ip address
**
** parameters:			UART port, IP Address
** Returned value:		Response
**
*****************************************************************************/
uint8_t* Wifly_Ping(uint8_t *ipRemote);

/*****************************************************************************
** Function name:		Wifly_Uptime
**
** Descriptions:		Send show time to know the uptime
**
** parameters:			UART port
** Returned value:		UpTime
**
*****************************************************************************/
uint8_t* Wifly_Uptime();

/*****************************************************************************
** Function name:		Wifly_GetIP
**
** Descriptions:		Send get ip to know the IP address
**
** parameters:			UART port
** Returned value:		IP address
**
*****************************************************************************/
uint8_t* Wifly_GetIP();

/*****************************************************************************
** Function name:		Wifly_GetChannel
**
** Descriptions:		Send show net to know the channel
**
** parameters:			UART port
** Returned value:		channel
**
*****************************************************************************/
int32_t Wifly_GetChannel();

/*****************************************************************************
** Function name:		Wifly_GetRSSI
**
** Descriptions:		Send show rssi' to know the signal in dBm
**
** parameters:			UART port
** Returned value:		RSSI
**
*****************************************************************************/
int32_t Wifly_GetRSSI();

/*****************************************************************************
** Function name:		Wifly_GetPower
**
** Descriptions:		Send get wlan to know the tx Power
**
** parameters:			UART port
** Returned value:		tx Power
**
*****************************************************************************/
int32_t Wifly_GetPower();

/*****************************************************************************
** Function name:		Wifly_SetPower
**
** Descriptions:		Change the transmission Power
**
** parameters:			UART port
** Returned value:		none
**
*****************************************************************************/
void Wifly_SetPower(uint8_t *txPower);

/*****************************************************************************
** Function name:		Wifly_Open
**
** Descriptions:		Send open
**
** parameters:			UART port
** Returned value:		none
**
*****************************************************************************/
void Wifly_Open();

/*****************************************************************************
** Function name:		Wifly_OpenHost
**
** Descriptions:		Send open with Address and remote port to open TCP
** 						connection
**
** parameters:			UART port, address and remote port, time autoconn
** Returned value:		TRUE is connect to host ok
**
*****************************************************************************/
uint8_t Wifly_OpenHost(uint8_t *host, uint8_t *remotePort, uint8_t *autoconn);

/*****************************************************************************
** Function name:		Wifly_SendDataHost
**
** Descriptions:		Send data to remote host
**
** parameters:			Data to send
** Returned value:		TRUE if the remote host replied ok
**
*****************************************************************************/
uint8_t Wifly_SendDataHost(uint8_t *data);

/*****************************************************************************
** Function name:		Wifly_ReceiveData
**
** Descriptions:		Receive data from UART
**
** parameters:			UART time out
** Returned value:		none
**
*****************************************************************************/
uint8_t Wifly_ReceiveData(uint32_t TimeOut);

/*****************************************************************************
** Function name:		Wifly_Close
**
** Descriptions:		Send close to close TCP connection
**
** parameters:			UART port
** Returned value:		none
**
*****************************************************************************/
void Wifly_Close();


#endif /* WIFLY_H_ */
