/*
 * adc.h
 *
 *  Created on: 28/05/2013
 *      Author: Miguel Angel Sanchez Munoz
 */

#include "adc.h"

volatile uint32_t ADCValue [4];
volatile uint32_t ADCIntDone = 0;

/*-----------------------------------------------------------*/

void ADC_Init(uint32_t ADC_Clk)
{
	uint32_t pclkdiv, pclk, i;

	//Enable CLOCK into ADC controler
	LPC_SC ->PCONP |= (1<<12);

	for (i=0; i<4; i++)
		{
		ADCValue [i] = 0x0;
		}



	//pin 15 is set to ADC input. AD0.0 P0.23 ~ AD0.3 P0.26
	LPC_PINCON->PINSEL1 &= ~0x003FC000;
	LPC_PINCON->PINSEL1 |= 0x00154000;
	//no pull-up no pull-down on this pin
	LPC_PINCON->PINMODE1 &= ~0x003FC000;
	LPC_PINCON->PINMODE1 |= 0x002A8000;
	//In the PCLKSEL0 register select PCLK_ADC to scale the clock for the ADC
	pclkdiv = (LPC_SC->PCLKSEL0 >> 24)& 0x03;
	switch (pclkdiv)
	{
		case 0x00:
		default:
			pclk = SystemCoreClock/4;
			break;
		case 0x01:
			pclk = SystemCoreClock;
			break;
		case 0x02:
			pclk = SystemCoreClock/2;
			break;
		case 0x03:
			pclk = SystemCoreClock/8;
			break;
	}
	LPC_ADC->ADCR = (0x01 << 0)| ((pclk / ADC_Clk -1) << 8) | (0 << 16)|(0<<17)|(1<<21)|(0<<24)|(0<<27);
	return;
}

/*-----------------------------------------------------------*/

uint32_t ADC_Read(uint8_t channelNum)
{
	uint32_t regVal, ADC_Data;


	if (channelNum >3) channelNum = 0;

	LPC_ADC->ADCR &= 0xFFFFFF00;
	LPC_ADC->ADCR |= (1 << 24) | (1 << channelNum);
	while (1) //wait until end of AD convert
	{
		switch (channelNum)
		{
		case 0: regVal = LPC_ADC->ADDR0;
		break;
		case 1: regVal = LPC_ADC->ADDR1;
		break;
		case 2: regVal = LPC_ADC->ADDR2;
		break;
		case 3: regVal = LPC_ADC->ADDR3;
		break;
		}

		//read the result of AD conversion
		if (regVal &ADC_DONE)
		{
			break;
		}
	}
LPC_ADC->ADCR &= 0xF8FFFFFF; //stop ADC
if (regVal & ADC_OVERRUN)
{
	return(0);
	}
ADC_Data = (regVal >> 4) & 0xFFF;

return (ADC_Data);
}

/******************************************************************************
**                            End Of File
******************************************************************************/
