/*
 * gpio.c
 *
 *  Created on: May 10, 2014
 *      Author: Miguel Angel Sanchez Muñoz
 *
 */

#include "gpio.h"

/*-----------------------------------------------------------*/

void pinSet ( uint8_t pin , uint8_t direction )
{

	if (pin < 16){
		/* We calculate the bit position to select the function on PINSEL register */
		uint8_t position = ( pin * 2 );
		/* We write 00 to select GPIO function */
		LPC_PINCON->PINSEL0 &= ( ~( 3 << position ) );
	} else {
		/* We calculate the bit position to select the function on PINSEL register */
		uint8_t position = ( pin - 16 ) * 2;
		/* We write 00 to select GPIO function */
		LPC_PINCON->PINSEL1 &= ( ~( 3 << position ) );
	}

	if ( direction == 0 ) LPC_GPIO0->FIODIR &= ( ~( 1 << pin ) ); // pin is selected as input

	if ( direction == 1 ) LPC_GPIO0->FIODIR |= ( 1 << pin ); // pin is selected as output

}

/*-----------------------------------------------------------*/

void pinWrite ( uint8_t pin , uint8_t value )
{

	if ( value == 0 ) LPC_GPIO0->FIOCLR = 1 << pin;

	if ( value == 1 ) LPC_GPIO0->FIOSET = 1 << pin;

}

/*-----------------------------------------------------------*/

uint32_t pinRead ( uint8_t pin )
{

	LPC_GPIO0->FIOMASK = ( ~( 1 << pin ) );

	return ( LPC_GPIO0->FIOPIN &  ( 1 << pin ) );

}

/*-----------------------------------------------------------*/

void pinToggle(uint8_t pin){

	uint32_t state = LPC_GPIO0->FIOPIN;

	LPC_GPIO0->FIOCLR = state & (1<<pin);
	LPC_GPIO0->FIOSET = (~state) & (1<<pin);
}

/*-----------------------------------------------------------*/

void initEINT0()
{
	// Set PINSEL4 [21:20] = 00 for P2.10 as GPIO
	LPC_PINCON->PINSEL4 &= ~(0x11 << 20);
	LPC_PINCON->PINSEL4 |= (0x01<<20); // P2.10 as external interupt

	//set the interrupt 2.10 for falling edge
	LPC_GPIOINT->IO2IntEnF &= ~(1<<10);

   // Enable External Interrupt 0
   NVIC_EnableIRQ(EINT0_IRQn );
}

/*-----------------------------------------------------------*/

void initEINT1()
{
	// Set PINSEL4 [23:22] = 00 for P2.11 as GPIO
	LPC_PINCON->PINSEL4 &= ~(0x11 << 22);
	LPC_PINCON->PINSEL4 |= (0x01<<22); // P2.11 as external interupt

	//set the interrupt 2.11 for falling edge
	LPC_GPIOINT->IO2IntEnF &= ~(1<<11);

	// Enable External Interrupt 1
	NVIC_EnableIRQ(EINT1_IRQn );
}

/******************************************************************************
**                            End Of File
******************************************************************************/
