/*
 * motor.c
 *
 *  Created on: Jun 4, 2014
 *      Author: Miguel Angel Sanchez Muñoz
 */

#include "motor.h"

uint8_t _steepPin;
uint8_t _resetPin;
uint8_t _dirRightPin;
uint8_t _dirLeftPin;

/*-----------------------------------------------------------*/

void Motor_Init(uint8_t steepPin, uint8_t resetPin, uint8_t dirRightPin, uint8_t dirLeftPin)
{
#ifdef DEBUG_MOTOR
	debug("INICIANDO MOTOR");
#endif

	_steepPin = steepPin;
	_resetPin = resetPin;
	_dirRightPin = dirRightPin;
	_dirLeftPin = dirLeftPin;

	pinSet(_resetPin, 1); //RESET
	pinSet(_steepPin, 1); //STEEP
	pinSet(_dirRightPin, 1); //DIR MOTOR 1
	pinSet(_dirLeftPin, 1); //DIR MOTOR 2

	Motor_Stop();

	return;

}

/*-----------------------------------------------------------*/

void Motor_Steep(uint32_t speed)
{
#ifdef DEBUG_MOTOR
	debug("MOTOR STEEP");
#endif

	pinWrite(_steepPin, 1);
	delayUs(1);
	pinWrite(_steepPin, 0);
	delayUs(speed);  // Min 750 Max 1700


	return;
}

/*-----------------------------------------------------------*/

void Motor_Start()
{
#ifdef DEBUG_MOTOR
	debug("MOTOR START");
#endif
	pinWrite(_resetPin, 1);

	return;
}

/*-----------------------------------------------------------*/

void Motor_Stop()
{
#ifdef DEBUG_MOTOR
	debug("MOTOR STOP");
#endif

	pinWrite(_resetPin, 0); //STOP motors
	delayMs(100);

	return;
}

/*-----------------------------------------------------------*/

void Motor_Go()
{
#ifdef DEBUG_MOTOR
	debug("MOTOR GO");
#endif

	pinWrite(_dirRightPin, 1);
	pinWrite(_dirLeftPin, 1);

	return;
}

/*-----------------------------------------------------------*/

void Motor_Back()
{
#ifdef DEBUG_MOTOR
	debug("MOTOR BACK");
#endif

	pinWrite(_dirRightPin, 0);
	pinWrite(_dirLeftPin, 0);

	return;
}

/*-----------------------------------------------------------*/

void Motor_DirRight()
{
#ifdef DEBUG_MOTOR
	debug("MOTOR RIGHT");
#endif

	pinWrite(_dirRightPin, 1);
	pinWrite(_dirLeftPin, 0);

	return;
}

/*-----------------------------------------------------------*/

void Motor_DirLeft()
{
#ifdef DEBUG_MOTOR
	debug("MOTOR LEFT");
#endif

	pinWrite(_dirRightPin, 0);
	pinWrite(_dirLeftPin, 1);
	return;
}

/*-----------------------------------------------------------*/

void Motor_DirRandom()
{
#ifdef DEBUG_MOTOR
	debug("MOTOR DIRECTION RANDOM");
#endif

	if((uint16_t) rand() % 2 == 0){
		Motor_DirLeft();
	} else {
		Motor_DirRight();
	}

	return;
}

/******************************************************************************
**                            End Of File
******************************************************************************/
