/*
 * wifly.c
 *
 *  Created on: Mar 24, 2014
 *      Author: Miguel Angel Sanchez Muñoz
 */


#include "wifly.h"

uint8_t portNum;

uint8_t *_host;
uint8_t *_remotePort;

static char Buffer[BUFSIZE];

xSemaphoreHandle xMutexWifly;

// Private Functions
void Wifly_CMD();

/*-----------------------------------------------------------*/

void Wifly_INIT(uint8_t UARTportNum, uint32_t baudrate)
{
	portNum = UARTportNum;

	xMutexWifly = xSemaphoreCreateRecursiveMutex();

	UARTInit(portNum, baudrate);

	delayMs(250);

	LPC_PINCON->PINSEL1 &= ( ~( 3 << 12 ) );
	LPC_GPIO0->FIODIR |= ( 1 << RST_WIFLY_PIN );

	LPC_GPIO0->FIOCLR = 1 << RST_WIFLY_PIN;
	delayMs(1);
	LPC_GPIO0->FIOSET = 1 << RST_WIFLY_PIN;

	//delayMs(2000);
}

/*-----------------------------------------------------------*/

void Wifly_Reboot()
{

	Wifly_CMD();

	xSemaphoreTake(xMutexWifly, portMAX_DELAY);

	Print_CRLF(portNum, (uint8_t *)"reboot");

	delayMs(1750);

	xSemaphoreGive(xMutexWifly);

	return;
}

/*-----------------------------------------------------------*/

void Wifly_Exit()
{

	xSemaphoreTake(xMutexWifly, portMAX_DELAY);

	Print_CRLF(portNum, (uint8_t *)"exit");

	xSemaphoreGive(xMutexWifly);

	return;
}

/*-----------------------------------------------------------*/

uint8_t Wifly_WlanConnection(uint8_t *ssid, uint8_t *mode, uint8_t *key)
{

	Wifly_CMD();

	xSemaphoreTake(xMutexWifly, portMAX_DELAY);

	Print_CRLF(portNum, (uint8_t *)"set wlan join 0");
	Print_Value_CRLF(portNum, (uint8_t *)"set wlan ssid", (uint8_t *)ssid);
	Print_Value_CRLF(portNum, (uint8_t *)"set wlan auth", (uint8_t *)mode);
	Print_Value_CRLF(portNum, (uint8_t *)"set wlan phrase", (uint8_t *)key);
	Print_Value_CRLF(portNum, (uint8_t *)"join", (uint8_t *)ssid);

	xSemaphoreGive(xMutexWifly);

	Wifly_ReceiveData(1000);

	Wifly_Exit(portNum);

	if(strstr(Buffer, (char *)"Associated!"))
	{
		return TRUE;
	}

	return FALSE;
}

/*-----------------------------------------------------------*/

uint8_t* Wifly_Ping(uint8_t *ipRemote)
{
	char *string;

	Wifly_CMD();

	xSemaphoreTake(xMutexWifly, portMAX_DELAY);

	Print_Value_CRLF(portNum, (uint8_t *)"ping", (uint8_t *)ipRemote);

	xSemaphoreGive(xMutexWifly);

	Wifly_ReceiveData(2500);

	string = strstr(Buffer, (char *)"reply");
	string = strtok(string, (char *)"\r\n");

	Wifly_Exit(portNum);

	return (uint8_t *)string;
}

/*-----------------------------------------------------------*/

uint8_t* Wifly_Uptime()
{
	char *string;
	char *upTime = "\0";

	Wifly_CMD();

	xSemaphoreTake(xMutexWifly, portMAX_DELAY);

	Print_CRLF(portNum, (uint8_t *)"show time");

	xSemaphoreGive(xMutexWifly);

	Wifly_ReceiveData(500);

	string = strstr(Buffer, (char *)"UpTime=");
	string = strtok(string, (char *)"\r\n");
	string = strtok(string, (char *)"=");
	do
	{
		if (string!=NULL) upTime = string;
		string = strtok(NULL,"=");
	} while ( string!=NULL );

	Wifly_Exit(portNum);

	return (uint8_t *) upTime;
}

/*-----------------------------------------------------------*/

uint8_t* Wifly_GetIP()
{
	char *string;
	char *ip = "\0";

	Wifly_CMD();

	xSemaphoreTake(xMutexWifly, portMAX_DELAY);

	Print_CRLF(portNum, (uint8_t *)"get ip");

	xSemaphoreGive(xMutexWifly);

	Wifly_ReceiveData(750);

	string = strstr(Buffer, (char *)"IP=");
	string = strtok(string, (char *)"\r\n");
	string = strtok(string, (char *)"=");
	do
	{
		if (string!=NULL) ip = string;
		string = strtok(NULL,"=");
	} while ( string!=NULL );
	ip = strtok(ip, (char *)":");

	Wifly_Exit(portNum);

	return (uint8_t *)ip;
}

/*-----------------------------------------------------------*/

int32_t Wifly_GetChannel()
{

	char *string;
	char *channel = "0";

	Wifly_CMD();

	xSemaphoreTake(xMutexWifly, portMAX_DELAY);

	Print_CRLF(portNum, (uint8_t *)"show net");

	xSemaphoreGive(xMutexWifly);

	Wifly_ReceiveData(750);

	string = strstr(Buffer, (char *)"Chan=");
	string = strtok(string, (char *)"\r\n");
	string = strtok(string, (char *)"=");
	do
	{
		if (string!=NULL) channel = string;
		string = strtok(NULL,"=");
	} while ( string!=NULL );

	Wifly_Exit(portNum);

	return atoi(channel);
}

/*-----------------------------------------------------------*/

int32_t Wifly_GetRSSI()
{
	char *string;
	char *rssi = "0";

	Wifly_CMD();

	xSemaphoreTake(xMutexWifly, portMAX_DELAY);

	Print_CRLF(portNum, (uint8_t *)"show rssi");

	xSemaphoreGive(xMutexWifly);

	Wifly_ReceiveData(750);

	string = strstr(Buffer, (char *)"RSSI=");
	string = strtok(string, (char *)"\r\n");
	string = strtok(string, (char *)"(");
	do
	{
		if (string!=NULL) rssi = string;
		string = strtok(NULL,"(");
	} while ( string!=NULL );

	rssi = strtok(rssi, (char *)")");

	Wifly_Exit(portNum);

	return atoi(rssi);
}

/*-----------------------------------------------------------*/

int32_t Wifly_GetPower()
{
	char *string;
	char *txPower = "0";

	Wifly_CMD();

	xSemaphoreTake(xMutexWifly, portMAX_DELAY);

	Print_CRLF(portNum, (uint8_t *)"get wlan");

	xSemaphoreGive(xMutexWifly);

	Wifly_ReceiveData(750);

	string = strstr(Buffer, (char *)"TxPower=");
	string = strtok(string, (char *)"\r\n");
	string = strtok(string, (char *)"=");
	do
	{
		if (string!=NULL) txPower = string;
		string = strtok(NULL,"=");
	} while ( string!=NULL );

	Wifly_Exit(portNum);

	return atoi(txPower);
}

/*-----------------------------------------------------------*/

void Wifly_SetPower(uint8_t *txPower)
{
	Wifly_CMD();

	xSemaphoreTake(xMutexWifly, portMAX_DELAY);

	Print_Value_CRLF(portNum, (uint8_t *)"set wlan tx", (uint8_t *)txPower);

	xSemaphoreGive(xMutexWifly);

	Wifly_Exit(portNum);

	return;
}

/*-----------------------------------------------------------*/

void Wifly_Open()
{

	Wifly_CMD();

	xSemaphoreTake(xMutexWifly, portMAX_DELAY);

	Print_CRLF(portNum, (uint8_t *)"open");

	xSemaphoreGive(xMutexWifly);

	return;
}

/*-----------------------------------------------------------*/

uint8_t Wifly_OpenHost(uint8_t *host, uint8_t *remotePort, uint8_t *autoconn)
{

	_host = host;
	_remotePort = remotePort;

	Wifly_CMD();

	xSemaphoreTake(xMutexWifly, portMAX_DELAY);

	sprintf(Buffer, "%s %s", (char *)_host, (char *)_remotePort);

	Print_Value_CRLF(portNum, (uint8_t *)"set sys autoconn", (uint8_t *)autoconn);
	Print_Value_CRLF(portNum, (uint8_t *)"open", (uint8_t *)Buffer);

	xSemaphoreGive(xMutexWifly);

	Wifly_ReceiveData(1000);

	if(strstr(Buffer, (char *)"*open*"))
	{
		return TRUE;
	}

	return FALSE;
}
/*-----------------------------------------------------------*/

uint8_t Wifly_SendDataHost(uint8_t *data)
{

	xSemaphoreTake(xMutexWifly, portMAX_DELAY);

	Print_CRLF(portNum, data);

	xSemaphoreGive(xMutexWifly);

	Wifly_ReceiveData(500);

	if(strstr(Buffer, (char *)"OK"))
	{
		return TRUE;
	}

	return FALSE;
}
/*-----------------------------------------------------------*/

uint8_t Wifly_ReceiveData(uint32_t TimeOut)
{
	xSemaphoreTake(xMutexWifly, portMAX_DELAY);

	UART_Receive(portNum, (uint8_t *)Buffer, TimeOut);

	xSemaphoreGive(xMutexWifly);

	#ifdef DEBUG_WIFLY
	debug((uint8_t *)Buffer);
	#endif

	return 0;
}
/*-----------------------------------------------------------*/

void Wifly_Close()
{
	Wifly_CMD();

	xSemaphoreTake(xMutexWifly, portMAX_DELAY);

	Print_CRLF(portNum, (uint8_t *)"close");

	xSemaphoreGive(xMutexWifly);

	Wifly_Exit(portNum);

	return;
}

/*-----------------------------------------------------------*/

/*****************************************************************************
** Function name:		Wifly_CMD
**
** Descriptions:		Send $$$ to enter at command mode
**
** parameters:			UART port
** Returned value:		none
**
*****************************************************************************/
void Wifly_CMD()
{

	xSemaphoreTake(xMutexWifly, portMAX_DELAY);

	Print(portNum, (uint8_t *)"$$$");

	xSemaphoreGive(xMutexWifly);

	return;
}

/******************************************************************************
**                            End Of File
******************************************************************************/









